# ffmpeg-utils
[![Build Status](https://travis-ci.org/livingbio/ffmpeg-utils.svg?branch=master)](https://travis-ci.org/livingbio/ffmpeg-utils)
[![PyPI version](https://badge.fury.io/py/livingbio-ffmpeg-utils.svg)](https://badge.fury.io/py/livingbio-ffmpeg-utils)
